==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/setup/ModuleInfo.hpp <==
#ifndef _COM_SUN_STAR_SETUP_MODULEINFO_HPP_
#define _COM_SUN_STAR_SETUP_MODULEINFO_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_SETUP_MODULEINFO_HDL_
#include "com/sun/star/setup/ModuleInfo.hdl"
#endif

#ifndef _COM_SUN_STAR_UNO_ANY_HXX_
#include "com/sun/star/uno/Any.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_SEQUENCE_HXX_
#include "com/sun/star/uno/Sequence.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace setup {

inline ModuleInfo::ModuleInfo() SAL_THROW( () )
    : strID()
    , strName()
    , strDescription()
    , strOnSelect()
    , strOnDeselect()
    , isMinimal(false)
    , isDefault(false)
    , isHiddenRoot(false)
    , isDontSelectByUser(false)
    , nSizeKB(0)
    , seqSubModules()
{
}

inline ModuleInfo::ModuleInfo(const ::rtl::OUString& strID_, const ::rtl::OUString& strName_, const ::rtl::OUString& strDescription_, const ::rtl::OUString& strOnSelect_, const ::rtl::OUString& strOnDeselect_, const ::sal_Bool& isMinimal_, const ::sal_Bool& isDefault_, const ::sal_Bool& isHiddenRoot_, const ::sal_Bool& isDontSelectByUser_, const ::sal_Int32& nSizeKB_, const ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Any >& seqSubModules_) SAL_THROW( () )
    : strID(strID_)
    , strName(strName_)
    , strDescription(strDescription_)
    , strOnSelect(strOnSelect_)
    , strOnDeselect(strOnDeselect_)
    , isMinimal(isMinimal_)
    , isDefault(isDefault_)
    , isHiddenRoot(isHiddenRoot_)
    , isDontSelectByUser(isDontSelectByUser_)
    , nSizeKB(nSizeKB_)
    , seqSubModules(seqSubModules_)
{
}

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::setup::ModuleInfo const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.setup.ModuleInfo");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
}

#endif // _COM_SUN_STAR_SETUP_MODULEINFO_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/setup/ModuleInfo.hpp <==
#ifndef _COM_SUN_STAR_SETUP_MODULEINFO_HPP_
#define _COM_SUN_STAR_SETUP_MODULEINFO_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_SETUP_MODULEINFO_HDL_
#include "com/sun/star/setup/ModuleInfo.hdl"
#endif

#ifndef _COM_SUN_STAR_UNO_ANY_HXX_
#include "com/sun/star/uno/Any.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_SEQUENCE_HXX_
#include "com/sun/star/uno/Sequence.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace setup {

inline ModuleInfo::ModuleInfo() SAL_THROW( () )
    : strID()
    , strName()
    , strDescription()
    , strOnSelect()
    , strOnDeselect()
    , isMinimal(false)
    , isDefault(false)
    , isHiddenRoot(false)
    , isDontSelectByUser(false)
    , nSizeKB(0)
    , seqSubModules()
{
}

inline ModuleInfo::ModuleInfo(const ::rtl::OUString& strID_, const ::rtl::OUString& strName_, const ::rtl::OUString& strDescription_, const ::rtl::OUString& strOnSelect_, const ::rtl::OUString& strOnDeselect_, const ::sal_Bool& isMinimal_, const ::sal_Bool& isDefault_, const ::sal_Bool& isHiddenRoot_, const ::sal_Bool& isDontSelectByUser_, const ::sal_Int32& nSizeKB_, const ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Any >& seqSubModules_) SAL_THROW( () )
    : strID(strID_)
    , strName(strName_)
    , strDescription(strDescription_)
    , strOnSelect(strOnSelect_)
    , strOnDeselect(strOnDeselect_)
    , isMinimal(isMinimal_)
    , isDefault(isDefault_)
    , isHiddenRoot(isHiddenRoot_)
    , isDontSelectByUser(isDontSelectByUser_)
    , nSizeKB(nSizeKB_)
    , seqSubModules(seqSubModules_)
{
}

} } } }

namespace com { namespace sun { namespace star { namespace setup {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::setup::ModuleInfo const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.setup.ModuleInfo");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::setup::ModuleInfo const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::setup::ModuleInfo >::get();
}

#endif // _COM_SUN_STAR_SETUP_MODULEINFO_HPP_
